"""
We have a text containing a poem, that is a sequence of verses with rhymes.
The poem is stored in a text file, one verse per line.

We want to analyze the poem to extract its prosodic structure, i.e. the repetition scheme of the poem.

To this aim we need the following definitions:
    - a 'sound element' (SE) is a maximal sequence of 1 or more consonants followed by 1 or more vowels: 
        - first all the consonants
        - then all the vowels (aeioujy)
        - all non-alphabetic chars like spaces, numbers, colon, comma etc. must be ignored
        - all accents from accented letters (e.g. è->e) must be removed
        - differences between uppercase and lowercase letters are disregarded
        NOTICE: the only exceptions are the first and the last SE of a verse, that could contain only vowels
                and only consonants, respectively.
    - a verse is made of a sequence of sound elements, the last of which is called 'final'
        Example:      
        If the verse is "Donàld Duck! wènt, to tHe seas'ìde to swim" 
            - the SEs are             [ 'do', 'na', 'lddu', 'ckwe', 'ntto', 'the', 'sea', 'si', 'de', 'to', 'swi', 'm' ]
            - the final SE is         'm'
            - the SE number (#SE) is  12
        notice that accents have been removed, letters are lowercase and non-alphabetic chars are ignored.
    - the prosodic structure of the poem is a list of numbers, one for each verse
    - the prosodic structure is obtained considering both the number of SE (#SE) and the final SE of the verses 
    - the first verse is associated with the number 0
    - each one of the following verses are associated:
        - with the same number associated to an earlier verse having the same #SE and final SE
        - or with a new number, obtained adding 1 to the greatest number already used
    - the period of the verses is the minimum number of verses that repeats with the same repetition schema.
    Example:
        If the poem is the text here below                  its sound elements are                                      #SE final   prosody
        '''
        Dì pestaggio tessessi allarmai, Partenopea!         di pe sta ggio te sse ssia lla rmai pa rte no pea           13  pea         0
        Sembrò svieremo imbarcate, aumentarono usurpai?     se mbro svie re moi mba rca teau me nta ro nou su rpai      14  rpai        1
        Flash privé spirereste? Pentecoste deturpai         fla shpri ve spi re re ste pe nte co ste de tu rpai         14  rpai        1
        scrost, direttamante arrischiai,                    scro stdi re tta ma ntea rri schiai                          8  schiai      2
        odi attuazione vernicera Partenopea.                o dia ttua zio ne ve rni ce ra pa rte no pea                13  pea         0
        Psion trentacinque preesistiti calzascarpe          psio ntre nta ci nque pree si sti ti ca lza sca rpe         13  rpe         3
        nobilt fiacchi vedesti avvertirsi spermatozoi?      no bi ltfia cchi ve de stia vve rti rsi spe rma to zoi      14  zoi         4
        Igloo rubi incassando giurati spermatozoi!          i gloo ru bii nca ssa ndo giu ra ti spe rma to zoi          14  zoi         4
        Saprai reputasse inebriai                           sa prai re pu ta ssei ne briai                               8  briai       5
        man l'ballaste segnaleremo soprascarpe.             ma nlba lla ste se gna le re mo so pra sca rpe              13  rpe         3
        '''
        the list of #SE is              [13,    14,     14,     8,        13,    13,    14,    14,    8,       13   ]
        the list of final SE is         ['pea', 'rpai', 'rpai', 'schiai', 'pea', 'rpe', 'zoi', 'zoi', 'briai', 'rpe']
        thus the prosodic structure is  [0,     1,      1,      2,        0,     3,     4,     4,     5,       3    ]

        From the prosodic structure you should find the period, i.e. the minimum length of verses that repeats with the same repetition schema.
        In this example the period is 5, in facts the prosody is obtained by repeating twice the [0, 1, 1, 2, 0] repetition schema,
            since the sequence [0, 1, 1, 2, 0] has the same schema of [3, 4, 4, 5, 3]

You have to define a function that analyzes the prosody of a poem stored in a file and returns a tuple with four elements, namely:
    - a list with the prosodic structure of the poem
    - an integer representing the period of the verses
    - a list with the number of Sound Elements (#SE) of each verse
    - a list with the final SE of each verses

    From the above example, the function should return the tuple
          ( [0, 1, 1, 2, 0, 3, 4, 4, 5, 3], 5, [13, 14, 14, 8, 13, 13, 14, 14, 8, 13 ], 
            ['pea', 'rpai', 'rpai', 'schiai', 'pea', 'rpe', 'zoi', 'zoi', 'briai', 'rpe'])

    NOTICE: you cannot use other libraries or open other files.
    TIMEOUT: The timeout for each test is 100ms (0.1 seconds)
"""

def ex1(poem_filename):
    # insert here your code
    pass
